@@ -91,8 +91,8 @@
 #define EVALSAMPLE 10000 /* sampling training data for evaluation */
 
 #define Nil 0 /* null pointer */
-#define false 0
-#define true 1
+#define binfalse 0
+#define bintrue 1
 #define None -1
 #define Epsilon 1E-4
 #define Width 80 /* approx max width of output */
@@ -281,7 +281,7 @@ typedef struct _env_rec {
   Boolean *DoNotUse;   /* atts precxluded from model */
   float *Gain;         /* gain from splitting on att */
   ContValue *Bar;      /* best threshold for contin att */
-  Boolean *Left;       /* true if v is in left subset */
+  Boolean *Left;       /* bintrue if v is in left subset */
   Set **Subset;        /* subset s for att a */
   Attribute *ModelAtt; /* atts used in current model */
   int NModelAtt;       /* number ditto */
@@ -296,7 +296,7 @@ typedef struct _env_rec {
       *Mean,          /* [Att] */
       *Var,           /* [Att] */
       *AvDev;         /* [Att] */
-  Boolean *ZeroCoeff, /* true if coeff to be set to zero */
+  Boolean *ZeroCoeff, /* bintrue if coeff to be set to zero */
       *SaveZero;      /* for SimplifyModel */
   DataRec *Filtered;  /* items minus outliers */
 } EnvRec, *Env;
