@@ -149,7 +149,7 @@ void initglobals(void)
 
   SAMPLE = 0.0;
   KRInit = 0;
-  LOCK = false;
+  LOCK = binfalse;
 
   MINITEMS = 0;
   MAXRULES = 100;
@@ -173,17 +173,17 @@ void setglobals(int unbiased, char *composite, int neighbors, int committees,
                 double sample, int seed, int rules, double extrapolation) {
   /* XXX What about setting FOLDS? */
 
-  UNBIASED = unbiased != 0 ? true : false;
+  UNBIASED = unbiased != 0 ? bintrue : binfalse;
 
   if (strcmp(composite, "yes") == 0) {
-    USEINSTANCES = true;
-    CHOOSEMODE = false;
+    USEINSTANCES = bintrue;
+    CHOOSEMODE = binfalse;
   } else if (strcmp(composite, "auto") == 0) {
-    USEINSTANCES = true;
-    CHOOSEMODE = true;
+    USEINSTANCES = bintrue;
+    CHOOSEMODE = bintrue;
   } else {
     USEINSTANCES = neighbors > 0;
-    CHOOSEMODE = false;
+    CHOOSEMODE = binfalse;
   }
 
   NN = neighbors;
